@@ -3,7 +3,7 @@ package Log::Dispatch::Email;
 use strict;
 use warnings;
 
-our $VERSION = '2.53';
+our $VERSION = '2.56';
 
 use Log::Dispatch::Output;
 
@@ -26,7 +26,7 @@ sub new {
                 type    => SCALAR,
                 default => "$program: log email"
             },
-            to => { type => SCALAR | ARRAYREF },
+            to   => { type => SCALAR | ARRAYREF },
             from => {
                 type     => SCALAR,
                 optional => 1
@@ -111,13 +111,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Email - Base class for objects that send log messages via email
 
 =head1 VERSION
 
-version 2.53
+version 2.56
 
 =head1 SYNOPSIS
 
@@ -192,11 +194,18 @@ clear the buffer.
 On destruction, the object will call C<flush()> to send any pending
 email.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
