@@ -3,7 +3,7 @@ package Log::Dispatch::Email::MailSend;
 use strict;
 use warnings;
 
-our $VERSION = '2.53';
+our $VERSION = '2.56';
 
 use Log::Dispatch::Email;
 
@@ -23,7 +23,7 @@ sub send_email {
     # Does this ever work for this module?
     $msg->set( 'From', $self->{from} ) if $self->{from};
 
-    local $?;
+    local ( $?, $@, $SIG{__DIE__} );
     eval {
         my $fh = $msg->open
             or die "Cannot open handle to mail program";
@@ -46,13 +46,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Email::MailSend - Subclass of Log::Dispatch::Email that uses the Mail::Send module
 
 =head1 VERSION
 
-version 2.53
+version 2.56
 
 =head1 SYNOPSIS
 
@@ -87,11 +89,18 @@ you could do:
 
 For more details, see the L<Mail::Mailer> docs.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
