@@ -3,7 +3,7 @@ package Log::Dispatch::File;
 use strict;
 use warnings;
 
-our $VERSION = '2.53';
+our $VERSION = '2.56';
 
 use Log::Dispatch::Output;
 
@@ -41,7 +41,7 @@ sub _basic_init {
     my %p = validate(
         @_, {
             filename => { type => SCALAR },
-            mode => {
+            mode     => {
                 type    => SCALAR,
                 default => '>'
             },
@@ -174,13 +174,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::File - Object for logging to files
 
 =head1 VERSION
 
-version 2.53
+version 2.56
 
 =head1 SYNOPSIS
 
@@ -270,11 +272,18 @@ which is probably not what you want.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
