@@ -3,7 +3,7 @@ package Log::Dispatch::Syslog;
 use strict;
 use warnings;
 
-our $VERSION = '2.54';
+our $VERSION = '2.56';
 
 use Log::Dispatch::Output;
 
@@ -65,10 +65,13 @@ sub _init {
     $self->{$_} = $p{$_} for qw( ident logopt facility socket lock );
     if ( $self->{lock} ) {
 
-        # These need to be loaded with use, not require.
-        eval 'use threads; use threads::shared'
-            unless $threads_loaded;
-        $threads_loaded = 1;
+        unless ($threads_loaded) {
+            local ( $@, $SIG{__DIE__} );
+
+            # These need to be loaded with use, not require.
+            eval 'use threads; use threads::shared';
+            $threads_loaded = 1;
+        }
         &threads::shared::share( \$thread_lock );
     }
 
@@ -92,6 +95,7 @@ sub log_message {
 
     lock($thread_lock) if $self->{lock};
 
+    local ( $@, $SIG{__DIE__} );
     eval {
         if ( defined $self->{socket} ) {
             Sys::Syslog::setlogsock(
@@ -121,13 +125,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Syslog - Object for logging to system log.
 
 =head1 VERSION
 
-version 2.54
+version 2.56
 
 =head1 SYNOPSIS
 
@@ -210,11 +216,18 @@ This defaults to false.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
